<?php

/**
 * @file
 * Contains theme override functions and preprocess functions for the Scratch
 * theme. Partly copied from Boron. A big thank you for this.
 */

/**
 * Changes the default meta content-type tag to the shorter HTML5 version.
 *
 * Adds a viewport meta tag for use in RWD.
 * @see http://drupal.org/node/1488756#comment-5747580
 *
 * Only implemented the basic viewport meta-tag, as I don’t have access to all
 * different phones.
 * Also removed the target-densitydpi.
 * @see http://sunpig.com/martin/archives/2012/03/18/goldilocks-and-the-three-device-pixel-ratios.html
 */
function scratch_html_head_alter(&$head_elements) {
  $head_elements['system_meta_content_type']['#attributes'] = array(
    'charset' => 'utf-8'
  );
  // uncomment if you want to use responsive styles
  // $head_elements['viewport'] = array(
  //   '#type' => 'html_tag',
  //   '#tag' => 'meta',
  //   '#attributes' => array(
  //     'name' => 'viewport',
  //     'content' => 'width=device-width, initial-scale=1.0',
  //   ),
  // );
  global $theme;
  $path = drupal_get_path('theme', $theme);
  global $base_path;
  $head_elements['apple_touch_icon'] = array(
    '#type' => 'html_tag',
    '#tag' => 'link',
    '#attributes' => array(
      'rel' => 'apple-touch-icon',
      'href' => $base_path . $path . '/_img/apple-touch-icon.png',
    ),
  );
  $head_elements['apple_touch_icon_ipad'] = array(
    '#type' => 'html_tag',
    '#tag' => 'link',
    '#attributes' => array(
      'rel' => 'apple-touch-icon',
      'href' => $base_path . $path . '/_img/apple-touch-icon-ipad.png',
      'sizes' => '72x72',
    ),
  );
  $head_elements['apple_touch_icon_iphone_retina'] = array(
    '#type' => 'html_tag',
    '#tag' => 'link',
    '#attributes' => array(
      'rel' => 'apple-touch-icon',
      'href' => $base_path . $path . '/_img/apple-touch-icon-iphone-retina.png',
      'sizes' => '114x114',
    ),
  );
  $head_elements['apple_touch_icon_ipad_retina'] = array(
    '#type' => 'html_tag',
    '#tag' => 'link',
    '#attributes' => array(
      'rel' => 'apple-touch-icon',
      'href' => $base_path . $path . '/_img/apple-touch-icon-ipad-retina.png',
      'sizes' => '144x144',
    ),
  );
}

/**
 * Changes the search form to use the HTML5 "search" input attribute.
 * And give the block a WAI-ARIA role="search".
 * @see http://drupal.org/node/1179668
 */
function search_preprocess_search_block_form(&$variables) {
  $variables['search_form'] = str_replace('type="text"', 'type="search"', $variables['search_form']);
}
function search_preprocess_block(&$variables) {
  if ($variables['block']->module == 'search') {
    $variables['attributes_array']['role'] = 'search';
  }
}

function contact_form_contact_site_form_alter(&$form, &$form_state, $form_id ) {
  // remove the subject input
  $form['subject']['#access'] = FALSE;
  // make the e-mailfield HTML5 (type="email")
  // dependancy: elements module
  $form['mail']['#type'] = 'emailfield';
  // add required role
  if ($form['mail']['#required']) {
    $form['mail']['#aria-required'] = 'true';
    // TODO: translate this to a proper attribute
    // TODO: than add this to all required fields
    // TODO: than do this for login as well
  }
  // var_export($form);
}

/**
 * Uses RDFa attributes if the RDF module is enabled
 * Lifted from Adaptivetheme for D7, full credit to Jeff Burnz
 * ref: http://drupal.org/node/887600
 */
function scratch_preprocess_html(&$vars) {
  if (module_exists('rdf')) {
    $vars['doctype'] = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML+RDFa 1.1//EN">' . "\n";
    $vars['rdf']->version = 'version="HTML+RDFa 1.1"';
    $vars['rdf']->namespaces = $vars['rdf_namespaces'];
    $vars['rdf']->profile = ' profile="' . $vars['grddl_profile'] . '"';
  } else {
    $vars['doctype'] = '<!DOCTYPE html>' . "\n";
    $vars['rdf']->version = '';
    $vars['rdf']->namespaces = '';
    $vars['rdf']->profile = '';
  }
}

/**
 * Implementation of hook_css_alter().
 * Removing certain core or module stylesheets.
 */
// function scratch_css_alter(&$css) {
//   foreach ($css as $file => $value) {
//     if (strpos($file, 'system.menus.css') !== FALSE) {
//       unset($css[$file]);
//     }
//   }
// }

/**
 * Implementing hook_breadcrumb().
 * Code taken from the Zen-theme. A big thank you to you too.
 */
function scratch_breadcrumb($variables) {
  $breadcrumb = $variables['breadcrumb'];

  // Return the breadcrumb with separators.
  if (!empty($breadcrumb)) {
    $breadcrumb_separator = " > ";
      $item = menu_get_item();
      if (!empty($item['tab_parent'])) {
        // If we are on a non-default tab, use the tab's title.
        $title = check_plain($item['title']);
      }
      else {
        $title = '<span class="current-title">'.drupal_get_title().'</span>';
      }
    // Provide a navigational heading to give context for breadcrumb links to
    // screen-reader users.
    if (empty($variables['title'])) {
      $variables['title'] = t('You are here');
    }
    // Unless overridden by a preprocess function, make the heading invisible.
    if (!isset($variables['title_attributes_array']['class'])) {
      $variables['title_attributes_array']['class'][] = 'element-invisible';
    }
    $heading = '<h2' . drupal_attributes($variables['title_attributes_array']) . '>' . $variables['title'] . '</h2>';

    return $heading . implode($breadcrumb_separator, $breadcrumb) . $breadcrumb_separator . $title;
  }
  // Otherwise, return an empty string.
  return '';
}

/**
 * Implementing template_preprocess_node()
 */
function scratch_preprocess_node(&$variables) {
  $variables['date'] = '<time datetime="' . format_date($variables['created'], 'custom', 'Y-m-d H:i:sP') .'" pubdate>' . format_date($variables['created'], 'long') . '</time>';
  // TODO: do the same for the changed date
}
